@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.90
- Written in Qt 4.4
+ version: 1.4
+ Written in Qt
  
                          datasetselectdialog.h  -  description
                              -------------------
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -28,8 +28,6 @@
 #define DATASETSELECTDIALOG_H
 
 #include <QDialog>
-
-
 #include "ui_datasetselectdialog.h"
  
 
@@ -38,12 +36,19 @@ class DataSetSelectDialog: public QDialog
 	Q_OBJECT
 public:
 	DataSetSelectDialog (QWidget *parent = 0);
+    ~DataSetSelectDialog();
 public slots:
 	void gatherData();
 signals:
 	void userChoices(QString);	
+private slots:
+    void on_buttonBox_accepted();
+
+    void on_buttonBox_rejected();
+
 private:
-	Ui::DataSetSelectDialog ui;
+    Ui::DataSetSelectDialog ui;
+    QStringList datasets_list, datasets_filenames;
 
 };
 
