@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.90
- Written in Qt 4.4
+ version: 1.4
+ Written in Qt
 
                         edge.cpp  -  description
                              -------------------
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -57,10 +57,10 @@ Edge::Edge(  GraphicsWidget *gw, Node *from, Node *to, float weight, int nodeSiz
 	m_reciprocal=reciprocal;
 	m_startOffset=source->size();  //used to offset edge from the centre of node
 	m_endOffset=target->size();  //used to offset edge from the centre of node	
-	qDebug("Edge() m_startOffset %i",(int) m_startOffset);
-	qDebug("Edge() m_endOffset %i",(int) m_endOffset);
+//	qDebug("Edge() m_startOffset %i",(int) m_startOffset);
+//	qDebug("Edge() m_endOffset %i",(int) m_endOffset);
 
-	m_arrowSize=5;		//controls the width of the edge arrow
+    m_arrowSize=4;		//controls the width of the edge arrow
 
 	eFrom = source->nodeNumber() ;
 	eTo = target->nodeNumber() ;
@@ -85,12 +85,6 @@ void Edge::removeRefs(){
 	target->deleteInLink(this);
 }
 
-void Edge::remove(){
-	qDebug("Edge: remove(), calling removeRefs()");
-	removeRefs();
-	this->hide();
-	
-}
 
 void Edge::setColor( QString str) {
 	m_color=str;
@@ -164,6 +158,9 @@ void Edge::addWeight (EdgeWeight* canvasWeight  )  {
 
 
 void Edge::clearWeightList(){
+        foreach (EdgeWeight *wgt, weightList) 		//Delete this weight
+            wgt->deleteLater();
+
 	weightList.clear();
 }
 
@@ -188,7 +185,7 @@ void Edge::adjust(){
  	
 	sourcePoint = line.p1() + edgeOffset;
 	targetPoint = line.p2() - edgeOffset;
-	qDebug()<<"----Edge: adjust() "<< sourcePoint.x()<< " "<<sourcePoint.y();
+//	qDebug()<<"----Edge: adjust() "<< sourcePoint.x()<< " "<<sourcePoint.y();
 	foreach (EdgeWeight *wgt, weightList) 		//Move the weight of this edge
 		wgt->setPos( (source->x()+target->x())/2.0, (source->y()+target->y())/2.0 );
 }
@@ -257,8 +254,12 @@ void Edge::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWid
 	if (!source || !target)
 		return;
 	Q_UNUSED(option); //	painter->setClipRect( option->exposedRect );
-	
-	qDebug()<<endl <<"@@@ Edge::paint() edge from "<< sourceNodeNumber() << " at (" <<(sourceNode())->x() <<","<< (sourceNode())->y() << ") to node "<<targetNodeNumber() << " at ("<<(targetNode())->x() <<","<< (targetNode())->y() << ") of weight "<< m_weight;
+    qDebug() <<"@@@ Edge::paint()";
+
+//    qDebug()<<endl <<"@@@ Edge::paint() edge from "<< sourceNodeNumber()
+//           << " at (" <<(sourceNode())->x() <<","<< (sourceNode())->y()
+//           << ") to node "<<targetNodeNumber() << " at ("<<(targetNode())->x()
+//           <<","<< (targetNode())->y() << ") of weight "<< m_weight;
 
 	//Define the path upon which we' ll draw the line 
 	QPainterPath line(sourcePoint);
@@ -266,23 +267,23 @@ void Edge::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWid
 	//Construct the path
 	if (source!=target) {
 		if ( !m_Bezier){
-			qDebug("*** Edge::paint(). Constructing a line");
+            qDebug()<< "*** Edge::paint(). Constructing a line";
 			line.lineTo(targetPoint);
 		}
 		else {
-			qDebug("*** Edge::paint(). Constructing a bezier curve");
+            qDebug() << "*** Edge::paint(). Constructing a bezier curve";
 		}
 	}
 	else { //self-link
 		QPointF c1 = QPointF( targetPoint.x() -30,  targetPoint.y() -30 );
 		QPointF c2 = QPointF( targetPoint.x() +30,  targetPoint.y() -30 );
-		qDebug()<<"*** Edge::paint(). Constructing a bezier self curve c1 "<<c1.x()<<","<<c1.y()
-						<< " and c2 "<<c2.x()<<","<<c2.y();
+        qDebug()<< "*** Edge::paint(). Constructing a bezier self curve c1 "
+                <<c1.x()<<","<<c1.y()  << " and c2 "<<c2.x()<<","<<c2.y();
 		line.cubicTo( c1, c2, targetPoint);
 	}
 
 	//Prepare the pen
-	qDebug()<<"*** Edge::paint(). Preparing the pen with width "<< width();
+//	qDebug()<<"*** Edge::paint(). Preparing the pen with width "<< width();
 	if (m_weight > 0)
 			painter->setPen(QPen(QColor(m_color), width(), Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
 	else 
@@ -297,47 +298,51 @@ void Edge::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWid
 		line_dy = targetPoint.y()-sourcePoint.y();
 		if ( line.length() >0 )
 			angle = ::acos( line_dx / line_length );
-		qDebug() << " acos() " << ::acos( line_dx  / line_length ) ;
+//		qDebug() << " acos() " << ::acos( line_dx  / line_length ) ;
 
 		if ( line_dy  >= 0)
 			angle = TwoPi - angle;
 
-		qDebug() << "*** Edge::paint(). Constructing arrows. First Arrow at target node" 
-					<< "target-source: " << line_dx
-					<< " length: " << line_length
-					<< " angle: "<< angle;
+//		qDebug() << "*** Edge::paint(). Constructing arrows. First Arrow at target node"
+//					<< "target-source: " << line_dx
+//					<< " length: " << line_length
+//					<< " angle: "<< angle;
 
 		QPointF destArrowP1 = targetPoint + QPointF(sin(angle - Pi / 3) * m_arrowSize,
 								cos(angle - Pi / 3) * m_arrowSize);
 		QPointF destArrowP2 = targetPoint + QPointF(sin(angle - Pi + Pi / 3) * m_arrowSize,
 								cos(angle - Pi + Pi / 3) * m_arrowSize);
-		qDebug() << "*** Edge::paint() destArrowP1 " <<  destArrowP1.x() << "," << destArrowP1.y() 
-								<< "  destArrowP2 " <<  destArrowP2.x() << "," << destArrowP2.y();
+//		qDebug() << "*** Edge::paint() destArrowP1 "
+//                 <<  destArrowP1.x() << "," << destArrowP1.y()
+//                  << "  destArrowP2 " <<  destArrowP2.x() << "," << destArrowP2.y();
 		painter->setBrush(QColor(m_color));
 		QPolygonF destP;
 		destP << targetPoint << destArrowP1 << destArrowP2;
 		line.addPolygon ( destP);
 		//painter->drawPolygon(QPolygonF() << line.p2() << destArrowP1 << destArrowP2);
 		if (m_reciprocal) { 
-			qDebug("**** Edge::paint() This edge is SYMMETRIC! So, we need to create Arrow at src node as well");
+            qDebug() << "**** Edge::paint() This edge is SYMMETRIC! "
+                     << " So, we need to create Arrow at src node as well";
 			QPointF srcArrowP1 = sourcePoint + QPointF(sin(angle +Pi / 3) * m_arrowSize,
 									cos(angle +Pi / 3) * m_arrowSize);
 			QPointF srcArrowP2 = sourcePoint + QPointF(sin(angle +Pi - Pi  / 3) * m_arrowSize,
 									cos(angle +Pi - Pi / 3) * m_arrowSize);
-			qDebug() << "*** Edge::paint() srcArrowP1 " <<  srcArrowP1.x() << "," << srcArrowP1.y() 
-									<< "  srcArrowP2 " <<  srcArrowP2.x() << "," << srcArrowP2.y();
+//			qDebug() << "*** Edge::paint() srcArrowP1 " <<  srcArrowP1.x() << "," << srcArrowP1.y()
+//									<< "  srcArrowP2 " <<  srcArrowP2.x() << "," << srcArrowP2.y();
 			QPolygonF srcP;
 			srcP << sourcePoint<< srcArrowP1<< srcArrowP2;
 			line.addPolygon ( srcP);
 
 //			painter->drawPolygon(QPolygonF() << line.p1() << srcArrowP1 << srcArrowP2);
 		}
-		else qDebug("*** Edge::paint() This edge is not symmetric. Therefore, I do not have anything else to do...");
+        else {
+            qDebug() << "*** Edge::paint() Not symmetric edge. Finish";
+        }
 	}
 	else {
 		qDebug()<< "*** Edge::paint(). This edge is self-link - CONTINUE!";
 	}
-	qDebug()<< "### Edge::paint(). DrawPath now....";
+//	qDebug()<< "### Edge::paint(). DrawPath now....";
 	painter->drawPath(line);
 }
 
@@ -346,21 +351,9 @@ void Edge::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWid
 	Controls the width of the edge; is a function of edge weight
 */
 float Edge::width(){
-	if ( fabs(m_weight) > 0 && fabs(m_weight) <=5) {
-		qDebug()<< "Edge::width() will return "<< fabs(m_weight);
-		return  fabs(m_weight);
-	}
-	else if (fabs(m_weight)  > 5 && fabs(m_weight) <=10) {
-		 return 6;
-	}
-	else if (fabs(m_weight) >10 && fabs(m_weight) <=20) {
-		return 7;
-	}
-	else if (fabs(m_weight) >20 && fabs(m_weight)<=30) {
-		return 8;
-	}
-	else if ( fabs(m_weight) > 30 ) return 9;
-	
+    qDebug()<< "Edge::width() will return "<< fabs(m_weight);
+    if ( fabs(m_weight) > 1  )
+        return  1  + fabs(m_weight)/10;
 	return 1;	//	Default, if  m_weight in (-1, 1) space  
 }
 
@@ -384,4 +377,11 @@ void Edge::mousePressEvent(QGraphicsSceneMouseEvent *event) {
 
 
 
+Edge::~Edge(){
+    qDebug() << "\n\n\n *** ~EDGE() " << sourceNodeNumber()<< "->" << targetNodeNumber();
+    removeRefs();
+    weightList.clear();
+    this->hide();
+
+}
 
