@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.90
- Written in Qt 4.4 with KDevelop 
+ version: 1.4
+ Written in Qt
 
                         edgeweight.cpp  -  description
                              -------------------
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -25,15 +25,20 @@
 ********************************************************************************/
 
 #include "edgeweight.h"
+#include "edge.h"
+#include <QDebug>
 #include <QFont>
 
 
-EdgeWeight::EdgeWeight( Edge *link , int size, QString labelText, QGraphicsScene *scene )
-: QGraphicsTextItem( 0, scene)
+EdgeWeight::EdgeWeight( Edge *link , int size, QString labelText)
+: QGraphicsTextItem( 0)
 {
+    qDebug()<< "EdgeWeight:: creating new edgeweight and attaching it to link";
 	link -> addWeight(this);
 	setPlainText( labelText );
-	this->setFont( QFont ("Courier", size, QFont::Light, TRUE) );
+    setParentItem(link); //auto disables child items like this, when link is disabled.
+    this->setFont( QFont ("Courier", size, QFont::Light, true) );
+    setZValue(253);
 }
 
 void EdgeWeight::move(double x, double y) {
