@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.90
- Written in Qt 4.4
+ version: 1.4
+ Written in Qt
 
                         graphicswidget.cpp description
                              -------------------
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -37,7 +37,7 @@
 #include "edge.h"
 #include "nodenumber.h"
 #include "nodelabel.h"
-#include "backgrcircle.h"
+#include "guide.h"
 #include "edgeweight.h"
 
 /** 
@@ -45,8 +45,8 @@
 */
 GraphicsWidget::GraphicsWidget( QGraphicsScene *sc, MainWindow* par)  : QGraphicsView ( sc,par) {
 	setScene(sc);
-	secondDoubleClick=FALSE;
-	dynamicMovement=FALSE;
+    secondDoubleClick=false;
+    dynamicMovement=false;
 	moving=0;
 	timerId=0;
 	layoutType=0;
@@ -55,6 +55,8 @@ GraphicsWidget::GraphicsWidget( QGraphicsScene *sc, MainWindow* par)  : QGraphic
 	m_currentScaleFactor = 1;
 	m_currentRotationAngle = 0;
 	markedNodeExists=false; //used in findNode()
+    edgesHash.reserve(10000);
+    nodeHash.reserve(500);
 }
 
 
@@ -74,17 +76,23 @@ void GraphicsWidget::paintEvent ( QPaintEvent * event ){
 	Clears the scene 
 */
 void GraphicsWidget::clear() {
-	int i=0;
+    qDebug() << " clear GW";
 	nodeHash.clear();
-	QList<QGraphicsItem *> allItems=scene()->items();
-	foreach (QGraphicsItem *item, allItems ) {
-		(item)->hide();
-		scene()->removeItem (item);
-		i++;
-	}
+    edgesHash.clear();
+    scene()->clear();
+    m_curRelation=0;
+
 }
 
-
+/**
+ * @brief GraphicsWidget::changeRelation
+ * Called from Graph::relationChanged(int) signal
+ * @param relation
+ */
+void GraphicsWidget::changeRelation(int relation) {
+    qDebug() << "GraphicsWidget::changeRelation() to " << relation;
+    m_curRelation = relation;
+}
 
 
 
@@ -116,12 +124,12 @@ void GraphicsWidget::drawNode(
 			);
 
 	//Drawing node label - label will be moved by the node movement (see last code line in this method)
-	NodeLabel *labelJim = new  NodeLabel (jim, labelSize, nodeLabel, scene() );
+    NodeLabel *labelJim = new  NodeLabel (jim, labelSize, nodeLabel );
 	labelJim -> setDefaultTextColor (labelColor);
 	labelJim -> setTextInteractionFlags(Qt::TextEditorInteraction);
 	
 	if (showLabels) {
-		//qDebug()<< "GW: drawNode: display label " <<  nodeLabel.toAscii() << " for node " << num;
+        //qDebug()<< "GW: drawNode: display label " <<  nodeLabel.toUtf8() << " for node " << num;
 	}
 	else {
 		//qDebug()<<"GW: drawNode: hiding label for node " << num;
@@ -132,7 +140,7 @@ void GraphicsWidget::drawNode(
 	if (numberInsideNode)
 		numberSize = size-2;
 
-	NodeNumber *numberJim = new  NodeNumber ( jim, numberSize, QString::number(num), scene() );
+    NodeNumber *numberJim = new  NodeNumber ( jim, numberSize, QString::number(num));
 	numberJim -> setDefaultTextColor (numberColor);
 	
 	if (!showNumbers){
@@ -153,36 +161,40 @@ void GraphicsWidget::drawNode(
 	b) when the user clicks on the AddLink button on the MW.
 */
 void GraphicsWidget::drawEdge(int i, int j, float weight, bool reciprocal, bool drawArrows, QString color, bool bezier){
-	qDebug()<<"GW: drawEdge ("<< i<< ","<< j<< ") with weight "<<weight << " - nodeHash reports "<< nodeHash.size()<<" nodes.";
+
+     QString edgeName = QString::number(m_curRelation) + QString(":")
+            + QString::number(i) + QString(">")+ QString::number(j);
+     qDebug()<<"GW: drawEdge "<< edgeName << "weight "<<weight
+            << " - nodeHash reports "<< nodeHash.size()<<" nodes.";
 	if (i == j ) {
 		bezier = true;		
 	}
-	qDebug()<< "GW: drawEdge() drawing edge now!"<< " From node "
-			<<  nodeHash.value(i)->nodeNumber()<< " to node "
-			<<  nodeHash.value(j)->nodeNumber() << " weight "
-			<< weight << " nodesize "
-			<<  m_nodeSize << " edgecolor "<< color ;
+//	qDebug()<< "GW: drawEdge() drawing edge now!"<< " From node "
+//			<<  nodeHash.value(i)->nodeNumber()<< " to node "
+//			<<  nodeHash.value(j)->nodeNumber() << " weight "
+//			<< weight << " nodesize "
+//			<<  m_nodeSize << " edgecolor "<< color ;
 	Edge *edge=new Edge (this, nodeHash.value(i), nodeHash.value(j), weight,
-			     m_nodeSize, color, reciprocal, drawArrows, bezier);
+                 m_nodeSize, color, reciprocal, drawArrows, bezier);
 	edge -> setZValue(253);		//Edges have lower z than nodes. Nodes always appear above edges.
 	// Keep it here so that it doesnt interfere with dashed lines.
 	edge->setBoundingRegionGranularity(0.05);	// Slows down the universe...Keep it 0.05...
 	//edge->setCacheMode (QGraphicsItem::DeviceCoordinateCache);  //Also slows down the universe...
 
-	QString edgeName = QString::number(i) + QString(">")+ QString::number(j);
-	qDebug()<<"GW: drawEdge() - adding new edge between "<<i << " and "<< j<< " to edgesMap. Name: "<<edgeName.toAscii();
-	edgesMap [edgeName] =  edge;
+//    qDebug()<<"GW: drawEdge() - adding new edge between "<<i << " and "<< j
+//           << " to edgesHash. Name: "<<edgeName.toUtf8();
+    edgesHash.insert(edgeName, edge);
 
-	qDebug()<< "GW: drawNode(): drawing edge weight number...";
+//    qDebug()<< "GW: drawEdge(): drawing edge weight number...";
 	double x = ( (nodeHash.value(i))->x() + (nodeHash.value(j))->x() ) / 2.0;
 	double y = ( (nodeHash.value(i))->y() + (nodeHash.value(j))->y() ) / 2.0;
-
-	EdgeWeight *edgeWeight = new  EdgeWeight (edge, 7, QString::number(weight), scene() );
+//    qDebug()<< "GW: drawEdge(): edge weight will be at " << x << ", " << y;
+    EdgeWeight *edgeWeight = new  EdgeWeight (edge, 7, QString::number(weight) );
 	edgeWeight-> setPos(x,y);
 	edgeWeight-> setDefaultTextColor (color);
 	edgeWeight-> hide();
 
-	qDebug()<< "Scene items now: "<< scene()->items().size() << " - GW items now: "<< items().size();
+//	qDebug()<< "Scene items now: "<< scene()->items().size() << " - GW items now: "<< items().size();
 }
 
 
@@ -193,9 +205,10 @@ void GraphicsWidget::drawEdge(int i, int j, float weight, bool reciprocal, bool
 */
 void GraphicsWidget::drawEdgeReciprocal(int source, int target){
 	qDebug("GW: drawEdgeReciprocal ()");
-	QString edgeName = QString::number(source) + QString(">")+ QString::number(target);
-	qDebug("GW: making existing edge between %i and %i reciprocal. Name: "+edgeName.toAscii(), source, target );
-	edgesMap [edgeName]->makeReciprocal();
+    QString edgeName = QString::number(m_curRelation) + QString(":") +
+            QString::number(source) + QString(">")+ QString::number(target);
+//    qDebug("GW: making existing edge between %i and %i reciprocal. Name: "+edgeName.toUtf8(), source, target );
+    edgesHash.value(edgeName)->makeReciprocal();
 }
 
 
@@ -205,9 +218,10 @@ void GraphicsWidget::drawEdgeReciprocal(int source, int target){
 */
 void GraphicsWidget::unmakeEdgeReciprocal(int source, int target){
 	qDebug("GW: unmakeEdgeReciprocal ()");
-	QString edgeName = QString::number(source) + QString(">")+ QString::number(target);
-	qDebug("GW: removing edge between %i and %i. Name: "+edgeName.toAscii(), source, target );
-	edgesMap [edgeName]->unmakeReciprocal();
+    QString edgeName =  QString::number(m_curRelation) + QString(":") +
+            QString::number(source) + QString(">")+ QString::number(target);
+//    qDebug("GW: removing edge between %i and %i. Name: "+edgeName.toUtf8(), source, target );
+    edgesHash.value(edgeName)->unmakeReciprocal();
 }
 
 
@@ -224,12 +238,12 @@ void GraphicsWidget::startEdge(Node *node){
 		secondNode=node;
 		emit userMiddleClicked(firstNode->nodeNumber(), secondNode->nodeNumber(), 1.0);
 		( (MainWindow*)parent() )->setCursor(Qt::ArrowCursor);
-		secondDoubleClick=FALSE;
+        secondDoubleClick=false;
 	}
 	else{
 		qDebug("GW: startEdge(): this is the first double click.");
 		firstNode=node;
-		secondDoubleClick=TRUE;
+        secondDoubleClick=true;
 		( (MainWindow*)parent() )->setCursor( Qt::PointingHandCursor); 
 	}
 }
@@ -263,6 +277,32 @@ void GraphicsWidget::edgeClicked(Edge *edge){
 
 
 
+/**
+    On the event of a right-click on a node, the node calls this function
+    to emit a signal to MW to open a context menu at the mouse position.
+    Node is already passed with selectedNode(Node *) signal
+    The position of the menu is determined by QMouse:pos()...
+*/
+void GraphicsWidget::openNodeContextMenu(){
+    qDebug("GW: emitting openNodeMenu()");
+    emit openNodeMenu();
+}
+
+
+/**
+    On the event of a right-click on an edge, the edge calls this function
+    to emit a signal to MW to open a context menu at the mouse position.
+    Edge is already passed with selectedEdge(Node *) signal
+    The position of the menu is determined by QMouse:pos()...
+*/
+void GraphicsWidget::openEdgeContextMenu(){
+    qDebug("GW: emitting openEdgeMenu()");
+    emit openEdgeMenu();
+}
+
+
+
+
 /** 
 	Called from each node when they move.
 	Updates 
@@ -281,7 +321,7 @@ void GraphicsWidget::nodeMoved(int number, int x, int y){
 	on the canvas  
 */
 void GraphicsWidget::moveNode(int number, int x, int y){
-	qDebug ("GW: updateNode() %i with %i, %i", number, x,y);
+//	qDebug ("GW: updateNode() %i with %i, %i", number, x,y);
 	nodeHash.value(number)->setPos(x,y);
 }
 
@@ -298,7 +338,6 @@ void GraphicsWidget::eraseNode(long int doomedJim){
 			Node *jim=(Node*) (*it);
 			if ( jim->nodeNumber()==doomedJim)	{
 				qDebug() << "GW: found doomedJim " <<  jim->nodeNumber() << " Demanding node->die() :)" ;
-				jim->die();
 				delete *it;
 				break;
 			}
@@ -336,9 +375,9 @@ void GraphicsWidget::eraseEdge(int sourceNode, int targetNode){
 
 /** 
 	Called from Node::die() to removeItem from nodeHash...
+    FIXME : Do we use it ????
 */
 void GraphicsWidget::removeItem( Node *node){
-	vector<Node*>::iterator it;
 	long int i=node->nodeNumber();
 	foreach ( Node *candidate, nodeHash) {
 		if ( candidate->nodeNumber() == i )
@@ -353,7 +392,7 @@ void GraphicsWidget::removeItem( Node *node){
 
 /** Called from Node::die() to remove Edge edge ... */
 void GraphicsWidget::removeItem( Edge * edge){
-	edge->remove();
+    //edge->remove();
 	delete (edge);
 }
 
@@ -515,26 +554,20 @@ void GraphicsWidget::setInitLabelDistance(int labelDistance){
 /**
 *	Changes the visibility of an GraphicsView edge (number, label, edge, etc)
 */
-void GraphicsWidget::setEdgeVisibility(int source, int target, bool visible){
-	QString edgeName = QString::number( source ) + QString(">")+ QString::number( target );
-	
-	if (visible) {
-		if  ( edgesMap.contains (edgeName) ) {
-			qDebug()<<"GW: setEdgeVisibility(). Making edge between "<< source  << " and "<< target 
-				<< " VISIBLE.";
-			edgesMap [edgeName] -> show();			
-		}
-		else {
-			
-		}
-	}
-	else {
-		if  ( edgesMap.contains (edgeName) ) {
-			qDebug()<<"GW: setEdgeVisibility(). Making edge between "<< source  << " and "<< target 
-				<< " NOT VISIBLE.";
-			edgesMap [edgeName] -> hide();
-		}
-	}
+void GraphicsWidget::setEdgeVisibility(int relation, int source, int target, bool toggle){
+    QString edgeName =  QString::number(relation) + QString(":") +
+            QString::number( source ) + QString(">")+ QString::number( target );
+
+    if  ( edgesHash.contains (edgeName) ) {
+        qDebug()<<"GW: setEdgeVisibility(). relation " << relation
+               << " : " << source  << " ->  "<< target << " to " << toggle;
+        edgesHash.value(edgeName) -> setVisible(toggle);
+        edgesHash.value(edgeName) -> setEnabled(toggle);
+        return;
+    }
+    qDebug()<<"GW: setEdgeVisibility(). Cannot find edge " << relation
+                   << " : " << source  << " ->  "<< target ;
+
 }
 
 
@@ -542,45 +575,64 @@ void GraphicsWidget::setEdgeVisibility(int source, int target, bool visible){
 /**
 *	Changes the visibility of a  Node
 */
-void GraphicsWidget::setNodeVisibility(long int number, bool visible){
-    qDebug() << "GW: setNodeVisibility() for "<< number;
-    QList<QGraphicsItem *> list = scene()->items();
-    for (QList<QGraphicsItem *>::iterator item=list.begin();item!=list.end(); item++) {
-	if ( (*item)->type() == TypeNode){
-	    if ( Node *node = qgraphicsitem_cast<Node *>(*item) )
-		if ( node->nodeNumber() == number ) {
-		    if (visible){
-			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Will be visible now...";
-			(*item)->show();
-		    }
-		    else {
-			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Invisible now...";
-			(*item)->hide();
-		    }
-		}
-	    }
+void GraphicsWidget::setNodeVisibility(long int number, bool toggle){
+    if  ( nodeHash.contains (number) ) {
+        qDebug() << "GW: setNodeVisibility(): for  "
+                 << number << " to " << toggle;
+        nodeHash.value(number) -> setVisible(toggle);
+        nodeHash.value(number) -> setEnabled(toggle);
+        return;
     }
-
-//	qDebug() << "GW: setNodeVisibility() for "<< number;
-//	foreach ( Node *candidate, nodeHash) {
-//		if (candidate->nodeNumber() == number ) {
-//		    if (visible) {
-//			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Will be visible now...";
-//			candidate->show();
-//			candidate->update();
-//		    }
-//		    else{
-//			qDebug() << "GW: setNodeVisibility(): Node numbered " << number << " found! Invisible now...";
-//			candidate->hide();
-//		    }
-//
-//			break;
-//		}
-//
-//	}
+        qDebug() << "GW: setNodeVisibility(): cannot find node " << number;
 }
 
 
+/**
+ * @brief GraphicsWidget::setNodeSize
+ * @param number
+ * @param size
+ * @return
+ */
+bool GraphicsWidget::setNodeSize(long int number, int size ){
+    qDebug () << " GraphicsWidget::setNodeSize() node: "<< number
+              << " new size "<< size;
+    if  ( nodeHash.contains (number) ) {
+            if (size>0){
+                qDebug() << "GW: setNodeSize(): for "<< number << " to " << size ;
+                nodeHash.value(number) -> setSize(size);
+                return true;
+
+            }
+            else {
+                qDebug() << "GW: setNodeSize(): for "<< number
+                         << " to initial size" << m_nodeSize;
+                nodeHash.value(number) -> setSize(m_nodeSize);
+                return true;
+
+            }
+    }
+        qDebug() << "GW: setNodeSize(): cannot find node " << number;
+    return false;
+}
+
+/**
+ * @brief GraphicsWidget::setAllNodeSize
+ * @param size
+ * @return
+ */
+void GraphicsWidget::setAllNodeSize(int size ){
+    qDebug() << "GW: setAllNodeSize() ";
+    foreach ( Node *m_node, nodeHash ) {
+        if (size>0){
+            qDebug() << "GW: setAllNodeSize(): "<< m_node->nodeNumber() << " to new size " << size ;
+            m_node -> setSize(size);
+        }
+        else {
+            qDebug() << "GW: setAllNodeSize(): "<< m_node->nodeNumber() << " to initial size " << m_nodeSize;
+            m_node -> setSize(m_nodeSize);
+        }
+    }
+}
 
 
 /*
@@ -588,11 +640,11 @@ void GraphicsWidget::setNodeVisibility(long int number, bool visible){
  * Returns, if found, the node with label or number 'text'
  */
 Node* GraphicsWidget::hasNode( QString text ){
-	vector<Node*>::iterator it;
+
 	bool ok = false;
 	foreach ( Node *candidate, nodeHash) {
 		if ( 	candidate->nodeNumber()==text.toInt(&ok, 10)  ||
-			candidate->labelText().contains (text, Qt::CaseInsensitive)
+            ( candidate->labelText() == text)
 			) {
 			qDebug() << "GW: hasNode(): Node " << text << " found!";
 			markedNodeExists=true;
@@ -638,6 +690,7 @@ bool GraphicsWidget::setMarkedNode(QString nodeText){
 void GraphicsWidget::setAllItemsVisibility(int type, bool visible){
 	QList<QGraphicsItem *> list = scene()->items();
 	for (QList<QGraphicsItem *>::iterator item=list.begin();item!=list.end(); item++) {
+        qDebug()<< "GW::setAllItemsVisibility. item type is " << (*item)->type();
 		if ( (*item)->type() == type){
 			if (visible)	(*item)->show();
 			else	(*item)->hide();
@@ -647,16 +700,16 @@ void GraphicsWidget::setAllItemsVisibility(int type, bool visible){
 
 
 
-void GraphicsWidget::addBackgrCircle( int x0, int y0, int radius){
-	BackgrCircle *circ=new BackgrCircle (this, x0, y0, radius);
+void GraphicsWidget::addGuideCircle( int x0, int y0, int radius){
+    Guide *circ=new Guide (this, x0, y0, radius);
 	circ->show();
 
 }
 
 
-void GraphicsWidget::addBackgrHLine( int y0){
-	BackgrCircle *circ=new BackgrCircle (this, y0, 	this->width());
-	circ->show();
+void GraphicsWidget::addGuideHLine( int y0){
+    Guide *line=new Guide (this, y0, 	this->width());
+    line->show();
 }
 
 
@@ -668,10 +721,10 @@ void GraphicsWidget::removeAllItems(int type){
 	QList<QGraphicsItem *> list = scene()->items();
 	for (QList<QGraphicsItem *>::iterator item=list.begin();item!=list.end(); item++) {
 		if ( (*item)->type() == type){
-			BackgrCircle *bgcircle = qgraphicsitem_cast<BackgrCircle *>  (*item);
+            Guide *guide = qgraphicsitem_cast<Guide *>  (*item);
 			qDebug()<< "GW: removeAllItems - located element";
-			bgcircle->die();
-			bgcircle->deleteLater ();
+            guide->die();
+            guide->deleteLater ();
 			delete *item;
 		}
 	}
@@ -679,9 +732,9 @@ void GraphicsWidget::removeAllItems(int type){
 
 
 
-void GraphicsWidget::clearBackgrCircles(){
-	qDebug()<< "GW: clearBackgrCircles";
-	this->removeAllItems(TypeBackgrCircle);
+void GraphicsWidget::clearGuides(){
+    qDebug()<< "GW: clearGuides";
+    this->removeAllItems(TypeGuide);
 }
 
 
@@ -739,6 +792,7 @@ void GraphicsWidget::mousePressEvent( QMouseEvent * e ) {
 		qDebug() << "GW: mousePressEvent(). No item here. "
 				<< "Starting a new selection rectangle or a new node";
 		this->scene()->clearSelection();
+        emit clearSelection(); //emit to MW that no node or edge is selected.
 		QGraphicsView::mousePressEvent(e);
 	} 
 
@@ -767,35 +821,6 @@ void GraphicsWidget::mousePressEvent( QMouseEvent * e ) {
 //}
 
 
-/** 	
-	On the event of a right-click on a node, the node calls this function
-	to emit a signal to MW to open a context menu at the mouse position.
-	Node is already passed with selectedNode(Node *) signal
-	The position of the menu is determined by QMouse:pos()...
-*/
-void GraphicsWidget::openNodeContextMenu(){
-	qDebug("GW: emitting openNodeMenu()");
-	emit openNodeMenu();
-}
-
-
-/** 	
-	On the event of a right-click on an edge, the edge calls this function
-	to emit a signal to MW to open a context menu at the mouse position.
-	Edge is already passed with selectedNode(Node *) signal
-	The position of the menu is determined by QMouse:pos()...
-*/
-void GraphicsWidget::openEdgeContextMenu(){
-	qDebug("GW: emitting openEdgeMenu()");
-	emit openEdgeMenu();
-}
-
-
-
-
-
-
-
 
 
 
@@ -852,9 +877,7 @@ void GraphicsWidget::changeZoom(int value) {
 	double scaleFactor = 0.25;
 	scaleFactor *= (value + 1);
 	m_currentScaleFactor = scaleFactor;
-	QMatrix oldMatrix = matrix();
 	resetMatrix();
-//	translate(oldMatrix.dx(), oldMatrix.dy());
 	this->scale(scaleFactor, scaleFactor);
 	rotate(m_currentRotationAngle);
 }
