@@ -1,12 +1,12 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer 
- version: 0.90
- Written in Qt 4.4
+ version: 1.4
+ Written in Qt
 
                         main.cpp  -  description
                              -------------------
-    begin                :  9 21:10:04 EET 2005
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    begin                : 9 21:10:04 EET 2005
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -49,8 +49,8 @@ int main(int argc, char *argv[])
   
 	//Check if a filename is passed when this program is called.
 	QString option;
-	if ( app.argc() > 1 )     {
-		option = app.argv()[1];
+    if ( argc > 1 )     {
+        option = argv[1];
 			if (option=="--help" || option=="-h" || option=="--h" ) {
 				cout<<"\nSocial Networks Visualizer v." << qPrintable(VERSION)<< "\n"
 					<<"\nUsage: socnetv [flags] [file]\n"
