@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.90
- Written in Qt 4.4
+ version: 1.4
+ Written in Qt
  
                          node.h  -  description
                           -------------------
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -58,20 +58,16 @@ class Node :  public QObject,  public QGraphicsItem {
 
 public:
 	Node(GraphicsWidget*, int num, int size, QString col, QString shape, bool, int, int, QPointF p) ;
-//	~Node();
+    ~Node();
 
 	enum { Type = UserType + 1 };
 	int type() const { return Type; }
 
-	void calculateForcesSpringEmbedder(bool dynamicMovement);
-	void calculateForcesFruchterman(bool dynamicMovement);
-
 
 	QRectF boundingRect() const;
 	QPainterPath shape() const;
 	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
 
-	void die(); 
 	long int nodeNumber() {return m_num;}
 
 	void setSize(int);
@@ -128,8 +124,7 @@ private:
 	QColor m_col;
 	bool m_hasNumber, m_hasLabel, m_isNumberInside;
 	/**Lists of elements attached to this node */
-	list<Edge*> inEdgeList, outEdgeList;
-	list<NodeNumber*> gfxNumberList;
+    list<Edge*> inEdgeList, outEdgeList;
 	NodeLabel *m_label;
 	NodeNumber *m_number;
 };
