@@ -1,11 +1,11 @@
 /****************************************************************************
 SocNetV: Social Networks Visualizer 
-version: 0.90
-Written in Qt 4.4 with KDevelop   
+version: 1.4
+Written in Qt
 
                                texteditor.cpp 
                              -------------------
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
 *****************************************************************************/
 
@@ -25,8 +25,7 @@ Written in Qt 4.4 with KDevelop
 ********************************************************************************/
 
 
-#include <QtGui>
-
+#include <QtWidgets>
 #include "texteditor.h"
 
 TextEditor::TextEditor(const QString &fileName)
