@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Networks Visualizer
- version: 0.90
- Written in Qt 4.4
+ version: 1.4
+ Written in Qt
  
-                         webcrawler.cpp  -  description
+                         webcrawler.h  -  description
                              -------------------
-    copyright            : (C) 2005-2010 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2014 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -30,7 +30,7 @@
 using namespace std;
 
 #include <QThread>
-
+#include <QNetworkReply>
 
 class Reader : public QThread  {
 	Q_OBJECT
@@ -39,7 +39,7 @@ public:
 	void createEdge (int source, int target);
 
 public slots:
-	void load();
+    void load(QNetworkReply*);
 signals:
 	void signalCreateNode(QString url, int no);
 	void signalCreateEdge (int source, int target);
